# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: mwaa
using AWS.Compat
using AWS.UUIDs

"""
    create_cli_token(name)
    create_cli_token(name, params::Dict{String,<:Any})

Create a CLI token to use Airflow CLI.

# Arguments
- `name`: Create a CLI token request for a MWAA environment.

"""
create_cli_token(Name; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/clitoken/$(Name)"; aws_config=aws_config)
create_cli_token(Name, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/clitoken/$(Name)", params; aws_config=aws_config)

"""
    create_environment(dag_s3_path, execution_role_arn, name, network_configuration, source_bucket_arn)
    create_environment(dag_s3_path, execution_role_arn, name, network_configuration, source_bucket_arn, params::Dict{String,<:Any})

JSON blob that describes the environment to create.

# Arguments
- `dag_s3_path`: The relative path to the DAG folder on your Amazon S3 storage bucket. For
  example, dags. For more information, see Importing DAGs on Amazon MWAA.
- `execution_role_arn`: The Amazon Resource Name (ARN) of the execution role for your
  environment. An execution role is an AWS Identity and Access Management (IAM) role that
  grants MWAA permission to access AWS services and resources used by your environment. For
  example, arn:aws:iam::123456789:role/my-execution-role. For more information, see Managing
  access to Amazon Managed Workflows for Apache Airflow.
- `name`: The name of your MWAA environment.
- `network_configuration`: The VPC networking components you want to use for your
  environment. At least two private subnet identifiers and one VPC security group identifier
  are required to create an environment. For more information, see Creating the VPC network
  for a MWAA environment.
- `source_bucket_arn`: The Amazon Resource Name (ARN) of your Amazon S3 storage bucket. For
  example, arn:aws:s3:::airflow-mybucketname.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"AirflowConfigurationOptions"`: The Apache Airflow configuration setting you want to
  override in your environment. For more information, see Environment configuration.
- `"AirflowVersion"`: The Apache Airflow version you want to use for your environment.
- `"EnvironmentClass"`: The environment class you want to use for your environment. The
  environment class determines the size of the containers and database used for your Apache
  Airflow services.
- `"KmsKey"`: The AWS Key Management Service (KMS) key to encrypt and decrypt the data in
  your environment. You can use an AWS KMS key managed by MWAA, or a custom KMS key
  (advanced). For more information, see Customer master keys (CMKs) in the AWS KMS developer
  guide.
- `"LoggingConfiguration"`: The Apache Airflow logs you want to send to Amazon CloudWatch
  Logs.
- `"MaxWorkers"`: The maximum number of workers that you want to run in your environment.
  MWAA scales the number of Apache Airflow workers and the Fargate containers that run your
  tasks up to the number you specify in this field. When there are no more tasks running, and
  no more in the queue, MWAA disposes of the extra containers leaving the one worker that is
  included with your environment.
- `"MinWorkers"`: The minimum number of workers that you want to run in your environment.
  MWAA scales the number of Apache Airflow workers and the Fargate containers that run your
  tasks up to the number you specify in the MaxWorkers field. When there are no more tasks
  running, and no more in the queue, MWAA disposes of the extra containers leaving the worker
  count you specify in the MinWorkers field.
- `"PluginsS3ObjectVersion"`: The plugins.zip file version you want to use.
- `"PluginsS3Path"`: The relative path to the plugins.zip file on your Amazon S3 storage
  bucket. For example, plugins.zip. If a relative path is provided in the request, then
  PluginsS3ObjectVersion is required. For more information, see Importing DAGs on Amazon MWAA.
- `"RequirementsS3ObjectVersion"`: The requirements.txt file version you want to use.
- `"RequirementsS3Path"`: The relative path to the requirements.txt file on your Amazon S3
  storage bucket. For example, requirements.txt. If a relative path is provided in the
  request, then RequirementsS3ObjectVersion is required. For more information, see Importing
  DAGs on Amazon MWAA.
- `"Tags"`: The metadata tags you want to attach to your environment. For more information,
  see Tagging AWS resources.
- `"WebserverAccessMode"`: The networking access of your Apache Airflow web server. A
  public network allows your Airflow UI to be accessed over the Internet by users granted
  access in your IAM policy. A private network limits access of your Airflow UI to users
  within your VPC. For more information, see Creating the VPC network for a MWAA environment.
- `"WeeklyMaintenanceWindowStart"`: The day and time you want MWAA to start weekly
  maintenance updates on your environment.
"""
create_environment(DagS3Path, ExecutionRoleArn, Name, NetworkConfiguration, SourceBucketArn; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("PUT", "/environments/$(Name)", Dict{String, Any}("DagS3Path"=>DagS3Path, "ExecutionRoleArn"=>ExecutionRoleArn, "NetworkConfiguration"=>NetworkConfiguration, "SourceBucketArn"=>SourceBucketArn); aws_config=aws_config)
create_environment(DagS3Path, ExecutionRoleArn, Name, NetworkConfiguration, SourceBucketArn, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("PUT", "/environments/$(Name)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("DagS3Path"=>DagS3Path, "ExecutionRoleArn"=>ExecutionRoleArn, "NetworkConfiguration"=>NetworkConfiguration, "SourceBucketArn"=>SourceBucketArn), params)); aws_config=aws_config)

"""
    create_web_login_token(name)
    create_web_login_token(name, params::Dict{String,<:Any})

Create a JWT token to be used to login to Airflow Web UI with claims based Authentication.

# Arguments
- `name`: Create an Airflow Web UI login token request for a MWAA environment.

"""
create_web_login_token(Name; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/webtoken/$(Name)"; aws_config=aws_config)
create_web_login_token(Name, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/webtoken/$(Name)", params; aws_config=aws_config)

"""
    delete_environment(name)
    delete_environment(name, params::Dict{String,<:Any})

Delete an existing environment.

# Arguments
- `name`: The name of the environment to delete.

"""
delete_environment(Name; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("DELETE", "/environments/$(Name)"; aws_config=aws_config)
delete_environment(Name, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("DELETE", "/environments/$(Name)", params; aws_config=aws_config)

"""
    get_environment(name)
    get_environment(name, params::Dict{String,<:Any})

Get details of an existing environment.

# Arguments
- `name`: The name of the environment to retrieve.

"""
get_environment(Name; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/environments/$(Name)"; aws_config=aws_config)
get_environment(Name, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/environments/$(Name)", params; aws_config=aws_config)

"""
    list_environments()
    list_environments(params::Dict{String,<:Any})

List Amazon MWAA Environments.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"MaxResults"`: The maximum results when listing MWAA environments.
- `"NextToken"`: The Next Token when listing MWAA environments.
"""
list_environments(; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/environments"; aws_config=aws_config)
list_environments(params::AbstractDict{String, Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/environments", params; aws_config=aws_config)

"""
    list_tags_for_resource(resource_arn)
    list_tags_for_resource(resource_arn, params::Dict{String,<:Any})

List the tags for MWAA environments.

# Arguments
- `resource_arn`: The ARN of the MWAA environment.

"""
list_tags_for_resource(ResourceArn; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/tags/$(ResourceArn)"; aws_config=aws_config)
list_tags_for_resource(ResourceArn, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("GET", "/tags/$(ResourceArn)", params; aws_config=aws_config)

"""
    publish_metrics(environment_name, metric_data)
    publish_metrics(environment_name, metric_data, params::Dict{String,<:Any})

An operation for publishing metrics from the customers to the Ops plane.

# Arguments
- `environment_name`: Publishes environment metric data to Amazon CloudWatch.
- `metric_data`: Publishes metric data points to Amazon CloudWatch. CloudWatch associates
  the data points with the specified metrica.

"""
publish_metrics(EnvironmentName, MetricData; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/metrics/environments/$(EnvironmentName)", Dict{String, Any}("MetricData"=>MetricData); aws_config=aws_config)
publish_metrics(EnvironmentName, MetricData, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/metrics/environments/$(EnvironmentName)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("MetricData"=>MetricData), params)); aws_config=aws_config)

"""
    tag_resource(resource_arn, tags)
    tag_resource(resource_arn, tags, params::Dict{String,<:Any})

Add tag to the MWAA environments.

# Arguments
- `resource_arn`: The tag resource ARN of the MWAA environments.
- `tags`: The tag resource tag of the MWAA environments.

"""
tag_resource(ResourceArn, Tags; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/tags/$(ResourceArn)", Dict{String, Any}("Tags"=>Tags); aws_config=aws_config)
tag_resource(ResourceArn, Tags, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("POST", "/tags/$(ResourceArn)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Tags"=>Tags), params)); aws_config=aws_config)

"""
    untag_resource(resource_arn, tag_keys)
    untag_resource(resource_arn, tag_keys, params::Dict{String,<:Any})

Remove a tag from the MWAA environments.

# Arguments
- `resource_arn`: The tag resource ARN of the MWAA environments.
- `tag_keys`: The tag resource key of the MWAA environments.

"""
untag_resource(ResourceArn, tagKeys; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("DELETE", "/tags/$(ResourceArn)", Dict{String, Any}("tagKeys"=>tagKeys); aws_config=aws_config)
untag_resource(ResourceArn, tagKeys, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("DELETE", "/tags/$(ResourceArn)", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("tagKeys"=>tagKeys), params)); aws_config=aws_config)

"""
    update_environment(name)
    update_environment(name, params::Dict{String,<:Any})

Update an MWAA environment.

# Arguments
- `name`: The name of your Amazon MWAA environment that you wish to update.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"AirflowConfigurationOptions"`: The Airflow Configuration Options to update of your
  Amazon MWAA environment.
- `"AirflowVersion"`: The Airflow Version to update of your Amazon MWAA environment.
- `"DagS3Path"`: The Dags folder S3 Path to update of your Amazon MWAA environment.
- `"EnvironmentClass"`: The Environment Class to update of your Amazon MWAA environment.
- `"ExecutionRoleArn"`: The Executio Role ARN to update of your Amazon MWAA environment.
- `"LoggingConfiguration"`: The Logging Configuration to update of your Amazon MWAA
  environment.
- `"MaxWorkers"`: The maximum number of workers to update of your Amazon MWAA environment.
- `"MinWorkers"`: The minimum number of workers to update of your Amazon MWAA environment.
- `"NetworkConfiguration"`: The Network Configuration to update of your Amazon MWAA
  environment.
- `"PluginsS3ObjectVersion"`: The Plugins.zip S3 Object Version to update of your Amazon
  MWAA environment.
- `"PluginsS3Path"`: The Plugins.zip S3 Path to update of your Amazon MWAA environment.
- `"RequirementsS3ObjectVersion"`: The Requirements.txt S3 ObjectV ersion to update of your
  Amazon MWAA environment.
- `"RequirementsS3Path"`: The Requirements.txt S3 Path to update of your Amazon MWAA
  environment.
- `"SourceBucketArn"`: The S3 Source Bucket ARN to update of your Amazon MWAA environment.
- `"WebserverAccessMode"`: The Webserver Access Mode to update of your Amazon MWAA
  environment.
- `"WeeklyMaintenanceWindowStart"`: The Weekly Maintenance Window Start to update of your
  Amazon MWAA environment.
"""
update_environment(Name; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("PATCH", "/environments/$(Name)"; aws_config=aws_config)
update_environment(Name, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = mwaa("PATCH", "/environments/$(Name)", params; aws_config=aws_config)
