# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: sms
using AWS.Compat
using AWS.UUIDs

"""
    create_app()
    create_app(params::Dict{String,<:Any})

Creates an application. An application consists of one or more server groups. Each server
group contain one or more servers.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"clientToken"`: A unique, case-sensitive identifier that you provide to ensure the
  idempotency of application creation.
- `"description"`: The description of the new application
- `"name"`: The name of the new application.
- `"roleName"`: The name of the service role in the customer's account to be used by AWS
  SMS.
- `"serverGroups"`: The server groups to include in the application.
- `"tags"`: The tags to be associated with the application.
"""
create_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("CreateApp"; aws_config=aws_config)
create_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("CreateApp", params; aws_config=aws_config)

"""
    create_replication_job(seed_replication_time, server_id)
    create_replication_job(seed_replication_time, server_id, params::Dict{String,<:Any})

Creates a replication job. The replication job schedules periodic replication runs to
replicate your server to AWS. Each replication run creates an Amazon Machine Image (AMI).

# Arguments
- `seed_replication_time`: The seed replication time.
- `server_id`: The ID of the server.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"description"`: The description of the replication job.
- `"encrypted"`: Indicates whether the replication job produces encrypted AMIs.
- `"frequency"`: The time between consecutive replication runs, in hours.
- `"kmsKeyId"`: The ID of the KMS key for replication jobs that produce encrypted AMIs.
  This value can be any of the following:   KMS key ID   KMS key alias   ARN referring to the
  KMS key ID   ARN referring to the KMS key alias    If encrypted is true but a KMS key ID is
  not specified, the customer's default KMS key for Amazon EBS is used.
- `"licenseType"`: The license type to be used for the AMI created by a successful
  replication run.
- `"numberOfRecentAmisToKeep"`: The maximum number of SMS-created AMIs to retain. The
  oldest is deleted after the maximum number is reached and a new AMI is created.
- `"roleName"`: The name of the IAM role to be used by the AWS SMS.
- `"runOnce"`: Indicates whether to run the replication job one time.
"""
create_replication_job(seedReplicationTime, serverId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("CreateReplicationJob", Dict{String, Any}("seedReplicationTime"=>seedReplicationTime, "serverId"=>serverId); aws_config=aws_config)
create_replication_job(seedReplicationTime, serverId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("CreateReplicationJob", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("seedReplicationTime"=>seedReplicationTime, "serverId"=>serverId), params)); aws_config=aws_config)

"""
    delete_app()
    delete_app(params::Dict{String,<:Any})

Deletes the specified application. Optionally deletes the launched stack associated with
the application and all AWS SMS replication jobs for servers in the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
- `"forceStopAppReplication"`: Indicates whether to stop all replication jobs corresponding
  to the servers in the application while deleting the application.
- `"forceTerminateApp"`: Indicates whether to terminate the stack corresponding to the
  application while deleting the application.
"""
delete_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteApp"; aws_config=aws_config)
delete_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteApp", params; aws_config=aws_config)

"""
    delete_app_launch_configuration()
    delete_app_launch_configuration(params::Dict{String,<:Any})

Deletes the launch configuration for the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
delete_app_launch_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppLaunchConfiguration"; aws_config=aws_config)
delete_app_launch_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppLaunchConfiguration", params; aws_config=aws_config)

"""
    delete_app_replication_configuration()
    delete_app_replication_configuration(params::Dict{String,<:Any})

Deletes the replication configuration for the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
delete_app_replication_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppReplicationConfiguration"; aws_config=aws_config)
delete_app_replication_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppReplicationConfiguration", params; aws_config=aws_config)

"""
    delete_app_validation_configuration(app_id)
    delete_app_validation_configuration(app_id, params::Dict{String,<:Any})

Deletes the validation configuration for the specified application.

# Arguments
- `app_id`: The ID of the application.

"""
delete_app_validation_configuration(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppValidationConfiguration", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
delete_app_validation_configuration(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteAppValidationConfiguration", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    delete_replication_job(replication_job_id)
    delete_replication_job(replication_job_id, params::Dict{String,<:Any})

Deletes the specified replication job. After you delete a replication job, there are no
further replication runs. AWS deletes the contents of the Amazon S3 bucket used to store
AWS SMS artifacts. The AMIs created by the replication runs are not deleted.

# Arguments
- `replication_job_id`: The ID of the replication job.

"""
delete_replication_job(replicationJobId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteReplicationJob", Dict{String, Any}("replicationJobId"=>replicationJobId); aws_config=aws_config)
delete_replication_job(replicationJobId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteReplicationJob", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("replicationJobId"=>replicationJobId), params)); aws_config=aws_config)

"""
    delete_server_catalog()
    delete_server_catalog(params::Dict{String,<:Any})

Deletes all servers from your server catalog.

"""
delete_server_catalog(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteServerCatalog"; aws_config=aws_config)
delete_server_catalog(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DeleteServerCatalog", params; aws_config=aws_config)

"""
    disassociate_connector(connector_id)
    disassociate_connector(connector_id, params::Dict{String,<:Any})

Disassociates the specified connector from AWS SMS. After you disassociate a connector, it
is no longer available to support replication jobs.

# Arguments
- `connector_id`: The ID of the connector.

"""
disassociate_connector(connectorId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DisassociateConnector", Dict{String, Any}("connectorId"=>connectorId); aws_config=aws_config)
disassociate_connector(connectorId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("DisassociateConnector", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("connectorId"=>connectorId), params)); aws_config=aws_config)

"""
    generate_change_set()
    generate_change_set(params::Dict{String,<:Any})

Generates a target change set for a currently launched stack and writes it to an Amazon S3
object in the customer’s Amazon S3 bucket.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application associated with the change set.
- `"changesetFormat"`: The format for the change set.
"""
generate_change_set(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GenerateChangeSet"; aws_config=aws_config)
generate_change_set(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GenerateChangeSet", params; aws_config=aws_config)

"""
    generate_template()
    generate_template(params::Dict{String,<:Any})

Generates an AWS CloudFormation template based on the current launch configuration and
writes it to an Amazon S3 object in the customer’s Amazon S3 bucket.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application associated with the AWS CloudFormation template.
- `"templateFormat"`: The format for generating the AWS CloudFormation template.
"""
generate_template(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GenerateTemplate"; aws_config=aws_config)
generate_template(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GenerateTemplate", params; aws_config=aws_config)

"""
    get_app()
    get_app(params::Dict{String,<:Any})

Retrieve information about the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
get_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetApp"; aws_config=aws_config)
get_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetApp", params; aws_config=aws_config)

"""
    get_app_launch_configuration()
    get_app_launch_configuration(params::Dict{String,<:Any})

Retrieves the application launch configuration associated with the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
get_app_launch_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppLaunchConfiguration"; aws_config=aws_config)
get_app_launch_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppLaunchConfiguration", params; aws_config=aws_config)

"""
    get_app_replication_configuration()
    get_app_replication_configuration(params::Dict{String,<:Any})

Retrieves the application replication configuration associated with the specified
application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
get_app_replication_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppReplicationConfiguration"; aws_config=aws_config)
get_app_replication_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppReplicationConfiguration", params; aws_config=aws_config)

"""
    get_app_validation_configuration(app_id)
    get_app_validation_configuration(app_id, params::Dict{String,<:Any})

Retrieves information about a configuration for validating an application.

# Arguments
- `app_id`: The ID of the application.

"""
get_app_validation_configuration(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppValidationConfiguration", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
get_app_validation_configuration(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppValidationConfiguration", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    get_app_validation_output(app_id)
    get_app_validation_output(app_id, params::Dict{String,<:Any})

Retrieves output from validating an application.

# Arguments
- `app_id`: The ID of the application.

"""
get_app_validation_output(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppValidationOutput", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
get_app_validation_output(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetAppValidationOutput", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    get_connectors()
    get_connectors(params::Dict{String,<:Any})

Describes the connectors registered with the AWS SMS.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The maximum number of results to return in a single call. The default
  value is 50. To retrieve the remaining results, make another call with the returned
  NextToken value.
- `"nextToken"`: The token for the next set of results.
"""
get_connectors(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetConnectors"; aws_config=aws_config)
get_connectors(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetConnectors", params; aws_config=aws_config)

"""
    get_replication_jobs()
    get_replication_jobs(params::Dict{String,<:Any})

Describes the specified replication job or all of your replication jobs.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The maximum number of results to return in a single call. The default
  value is 50. To retrieve the remaining results, make another call with the returned
  NextToken value.
- `"nextToken"`: The token for the next set of results.
- `"replicationJobId"`: The ID of the replication job.
"""
get_replication_jobs(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetReplicationJobs"; aws_config=aws_config)
get_replication_jobs(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetReplicationJobs", params; aws_config=aws_config)

"""
    get_replication_runs(replication_job_id)
    get_replication_runs(replication_job_id, params::Dict{String,<:Any})

Describes the replication runs for the specified replication job.

# Arguments
- `replication_job_id`: The ID of the replication job.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The maximum number of results to return in a single call. The default
  value is 50. To retrieve the remaining results, make another call with the returned
  NextToken value.
- `"nextToken"`: The token for the next set of results.
"""
get_replication_runs(replicationJobId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetReplicationRuns", Dict{String, Any}("replicationJobId"=>replicationJobId); aws_config=aws_config)
get_replication_runs(replicationJobId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetReplicationRuns", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("replicationJobId"=>replicationJobId), params)); aws_config=aws_config)

"""
    get_servers()
    get_servers(params::Dict{String,<:Any})

Describes the servers in your server catalog. Before you can describe your servers, you
must import them using ImportServerCatalog.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"maxResults"`: The maximum number of results to return in a single call. The default
  value is 50. To retrieve the remaining results, make another call with the returned
  NextToken value.
- `"nextToken"`: The token for the next set of results.
- `"vmServerAddressList"`: The server addresses.
"""
get_servers(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetServers"; aws_config=aws_config)
get_servers(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("GetServers", params; aws_config=aws_config)

"""
    import_app_catalog()
    import_app_catalog(params::Dict{String,<:Any})

Allows application import from AWS Migration Hub.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"roleName"`: The name of the service role. If you omit this parameter, we create a
  service-linked role for AWS Migration Hub in your account. Otherwise, the role that you
  provide must have the policy and trust policy described in the AWS Migration Hub User Guide.
"""
import_app_catalog(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ImportAppCatalog"; aws_config=aws_config)
import_app_catalog(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ImportAppCatalog", params; aws_config=aws_config)

"""
    import_server_catalog()
    import_server_catalog(params::Dict{String,<:Any})

Gathers a complete list of on-premises servers. Connectors must be installed and monitoring
all servers to import. This call returns immediately, but might take additional time to
retrieve all the servers.

"""
import_server_catalog(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ImportServerCatalog"; aws_config=aws_config)
import_server_catalog(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ImportServerCatalog", params; aws_config=aws_config)

"""
    launch_app()
    launch_app(params::Dict{String,<:Any})

Launches the specified application as a stack in AWS CloudFormation.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
launch_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("LaunchApp"; aws_config=aws_config)
launch_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("LaunchApp", params; aws_config=aws_config)

"""
    list_apps()
    list_apps(params::Dict{String,<:Any})

Retrieves summaries for all applications.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appIds"`: The unique application IDs.
- `"maxResults"`: The maximum number of results to return in a single call. The default
  value is 100. To retrieve the remaining results, make another call with the returned
  NextToken value.
- `"nextToken"`: The token for the next set of results.
"""
list_apps(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ListApps"; aws_config=aws_config)
list_apps(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("ListApps", params; aws_config=aws_config)

"""
    notify_app_validation_output(app_id)
    notify_app_validation_output(app_id, params::Dict{String,<:Any})

Provides information to AWS SMS about whether application validation is successful.

# Arguments
- `app_id`: The ID of the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"notificationContext"`: The notification information.
"""
notify_app_validation_output(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("NotifyAppValidationOutput", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
notify_app_validation_output(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("NotifyAppValidationOutput", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    put_app_launch_configuration()
    put_app_launch_configuration(params::Dict{String,<:Any})

Creates or updates the launch configuration for the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
- `"autoLaunch"`: Indicates whether the application is configured to launch automatically
  after replication is complete.
- `"roleName"`: The name of service role in the customer's account that AWS CloudFormation
  uses to launch the application.
- `"serverGroupLaunchConfigurations"`: Information about the launch configurations for
  server groups in the application.
"""
put_app_launch_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppLaunchConfiguration"; aws_config=aws_config)
put_app_launch_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppLaunchConfiguration", params; aws_config=aws_config)

"""
    put_app_replication_configuration()
    put_app_replication_configuration(params::Dict{String,<:Any})

Creates or updates the replication configuration for the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
- `"serverGroupReplicationConfigurations"`: Information about the replication
  configurations for server groups in the application.
"""
put_app_replication_configuration(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppReplicationConfiguration"; aws_config=aws_config)
put_app_replication_configuration(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppReplicationConfiguration", params; aws_config=aws_config)

"""
    put_app_validation_configuration(app_id)
    put_app_validation_configuration(app_id, params::Dict{String,<:Any})

Creates or updates a validation configuration for the specified application.

# Arguments
- `app_id`: The ID of the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appValidationConfigurations"`: The configuration for application validation.
- `"serverGroupValidationConfigurations"`: The configuration for instance validation.
"""
put_app_validation_configuration(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppValidationConfiguration", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
put_app_validation_configuration(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("PutAppValidationConfiguration", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    start_app_replication()
    start_app_replication(params::Dict{String,<:Any})

Starts replicating the specified application by creating replication jobs for each server
in the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
start_app_replication(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartAppReplication"; aws_config=aws_config)
start_app_replication(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartAppReplication", params; aws_config=aws_config)

"""
    start_on_demand_app_replication(app_id)
    start_on_demand_app_replication(app_id, params::Dict{String,<:Any})

Starts an on-demand replication run for the specified application.

# Arguments
- `app_id`: The ID of the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"description"`: The description of the replication run.
"""
start_on_demand_app_replication(appId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartOnDemandAppReplication", Dict{String, Any}("appId"=>appId); aws_config=aws_config)
start_on_demand_app_replication(appId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartOnDemandAppReplication", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("appId"=>appId), params)); aws_config=aws_config)

"""
    start_on_demand_replication_run(replication_job_id)
    start_on_demand_replication_run(replication_job_id, params::Dict{String,<:Any})

Starts an on-demand replication run for the specified replication job. This replication run
starts immediately. This replication run is in addition to the ones already scheduled.
There is a limit on the number of on-demand replications runs that you can request in a
24-hour period.

# Arguments
- `replication_job_id`: The ID of the replication job.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"description"`: The description of the replication run.
"""
start_on_demand_replication_run(replicationJobId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartOnDemandReplicationRun", Dict{String, Any}("replicationJobId"=>replicationJobId); aws_config=aws_config)
start_on_demand_replication_run(replicationJobId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StartOnDemandReplicationRun", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("replicationJobId"=>replicationJobId), params)); aws_config=aws_config)

"""
    stop_app_replication()
    stop_app_replication(params::Dict{String,<:Any})

Stops replicating the specified application by deleting the replication job for each server
in the application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
stop_app_replication(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StopAppReplication"; aws_config=aws_config)
stop_app_replication(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("StopAppReplication", params; aws_config=aws_config)

"""
    terminate_app()
    terminate_app(params::Dict{String,<:Any})

Terminates the stack for the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
"""
terminate_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("TerminateApp"; aws_config=aws_config)
terminate_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("TerminateApp", params; aws_config=aws_config)

"""
    update_app()
    update_app(params::Dict{String,<:Any})

Updates the specified application.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"appId"`: The ID of the application.
- `"description"`: The new description of the application.
- `"name"`: The new name of the application.
- `"roleName"`: The name of the service role in the customer's account used by AWS SMS.
- `"serverGroups"`: The server groups in the application to update.
- `"tags"`: The tags to associate with the application.
"""
update_app(; aws_config::AbstractAWSConfig=global_aws_config()) = sms("UpdateApp"; aws_config=aws_config)
update_app(params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("UpdateApp", params; aws_config=aws_config)

"""
    update_replication_job(replication_job_id)
    update_replication_job(replication_job_id, params::Dict{String,<:Any})

Updates the specified settings for the specified replication job.

# Arguments
- `replication_job_id`: The ID of the replication job.

# Optional Parameters
Optional parameters can be passed as a `params::Dict{String,<:Any}`. Valid keys are:
- `"description"`: The description of the replication job.
- `"encrypted"`: When true, the replication job produces encrypted AMIs. For more
  information, KmsKeyId.
- `"frequency"`: The time between consecutive replication runs, in hours.
- `"kmsKeyId"`: The ID of the KMS key for replication jobs that produce encrypted AMIs.
  This value can be any of the following:   KMS key ID   KMS key alias   ARN referring to the
  KMS key ID   ARN referring to the KMS key alias   If encrypted is enabled but a KMS key ID
  is not specified, the customer's default KMS key for Amazon EBS is used.
- `"licenseType"`: The license type to be used for the AMI created by a successful
  replication run.
- `"nextReplicationRunStartTime"`: The start time of the next replication run.
- `"numberOfRecentAmisToKeep"`: The maximum number of SMS-created AMIs to retain. The
  oldest is deleted after the maximum number is reached and a new AMI is created.
- `"roleName"`: The name of the IAM role to be used by AWS SMS.
"""
update_replication_job(replicationJobId; aws_config::AbstractAWSConfig=global_aws_config()) = sms("UpdateReplicationJob", Dict{String, Any}("replicationJobId"=>replicationJobId); aws_config=aws_config)
update_replication_job(replicationJobId, params::AbstractDict{String, <:Any}; aws_config::AbstractAWSConfig=global_aws_config()) = sms("UpdateReplicationJob", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("replicationJobId"=>replicationJobId), params)); aws_config=aws_config)
